@@ -22,6 +22,6 @@ import numpy
 
 def GenGaussSet (vl, evl, ntrial=100):
     if evl != 0.0:
-        return numpy.random.normal(vl,evl,ntrial)
+        return numpy.random.normal(vl,2*evl,ntrial)
     else:
         return vl
\ No newline at end of file
