@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Statistics
-Version : 1.2.1
+Version : 1.3.0
 Author  : Stefano Covino
-Date    : 27/08/2012
+Date    : 04/12/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -22,6 +22,6 @@ History : (28/10/2010) First version.
 
 
 __all__ = ['AsymmetricGaussianDistrib', 'AverIterSigmaClipp', 'AverSigmaClippFrame', 
-           'AverSigmaClippFrameFast', 'ChSqIncrement', 'CoordDistanceMinimization', 
+           'AverSigmaClippFrameFast', 'ChSqIncrement', 'CoordDistanceMinimization', 'GenFitPars',
            'GenGaussSet', 'ScoreatPercentile', 'WeightedMean', 'WeightedMeanFrame']
 
