@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.58
+Version : 1.1.2
 Author  : Stefano Covino
-Date    : 28/08/2012
+Date    : 06/12/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -76,6 +76,11 @@ History : (28/09/2010) First named version.
         : (17/06/2012) V. 3.10.6b3.
         : (31/07/2012) V. 3.10.6b4.
         : (28/08/2012) V. 3.10.6.
+        : (31/08/2012) V. 3.10.7b1.
+        : (20/09/2012) V. 3.10.7b2.
+        : (27/09/2012) V. 3.10.7b3 and SRPTime.
+        : (04/12/2012) V. 3.10.7b4.
+        : (06/12/2012) V. 3.10.7.
 """
 
 
@@ -86,9 +91,9 @@ import pkg_resources
 
 __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhotometry', 
            'SRPPipelines', 'SRPPolarimetry', 'SRPREM', 'SRPSky', 'SRPSpectroscopy', 
-           'SRPStatistics', 'SRPSystem', 'SRPTables', 'SRPTNG']
+           'SRPStatistics', 'SRPSystem', 'SRPTables', 'SRPTime', 'SRPTNG']
 
 
 # Version
-__version__ = '3.10.6'
+__version__ = '3.10.7'
 
